@@ -3,7 +3,7 @@ import ctypes as ct
 
 # SF-fmt, SF-typ,  np,        ct,  struc
 table = [ \
-  [    1,    0,    np.int8,   ct.c_byte, 'c', 'BYTE'        ],
+  [    1,    0,    np.int8,   ct.c_byte, 'b', 'BYTE'        ],
   [    2,    6,    np.str_,   ct.c_char, 'c', 'CHAR'        ],
   [    3,   11,   np.int16,  ct.c_int16, 'h', 'SHORT_INT'   ],
   [    4,    1,   np.int32,  ct.c_int32, 'i', 'INTEGER'     ],
@@ -33,17 +33,24 @@ fmt2typ   = dict( zip(typ_tab[0], typ_tab[1]) )
 for key in fmt2len.keys():
     fmt2typ[key] = 6
 
+# /usr/ads/codes
+#  objects
 obj_name = {1: 'Diagnostic', 2: 'List', 3: 'Device', 4: 'Param_Set', \
             5: 'Map_Func', 6: 'Signal Group', 7: 'Signal', 8: 'Time Base', \
             9: 'SF_List', 10: 'Algorithm', 11: 'Update_Set', \
             12: 'Loc_Timer', 13: 'Area Base', 14: 'Qualifier', \
             15: 'ModObj', 16: 'Map_Extd', 17: 'Resource', 18: 'ADDRLEN'}
-
+#  calibration
 cal_type = {0: 'NoCalib', 1: 'LinCalib', 2: 'LookUp-Tab', 3: 'extCalib'}
 
+#  timebases
 tbtype_d = { \
-  0: 'ADC_intern', 1: 'PPG_prog', 2: 'Datablock'}
+  0: 'ADC_intern', 1: 'PPG_prog', 2: 'Datablock', 4: 'Chain', 5: 'Condensed'}
 
+#  addrsizes
+addrsizes = { 0: 1, 1: 1024, 2: 4096, 3: 8192}
+
+#  dimensions
 unit_d = { \
   0:None, 1:'kg', 2:'m', 3:'V', 4:'A', 5:'mV', 6:'eV', 7:'J', 8:'s', 9:'min', 10:'h', \
   11:'Celsius', 12:'pm', 13:'msec', 14:'1/V', 15:'K', 16:'degree', 17:'keV', 18:'cm', \
